# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/log.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='masterful/proto/log.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x19masterful/proto/log.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"y\n\x08\x41piEvent\x12\x1b\n\x04type\x18\x01 \x01(\x0e\x32\r.ApiEventType\x12\x12\n\nmodel_spec\x18\x02 \x01(\x0c\x12\x18\n\x10\x65xtra_model_spec\x18\x03 \x01(\x0c\x12\x11\n\tdata_spec\x18\x04 \x01(\x0c\x12\x0f\n\x07version\x18\x05 \x01(\x05\"\xb7\x01\n\x0c\x44\x61tasetEvent\x12\x1b\n\x13labeled_cardinality\x18\x01 \x01(\x05\x12\x1e\n\x16validation_cardinality\x18\x02 \x01(\x05\x12\x1d\n\x15unlabeled_cardinality\x18\x03 \x01(\x05\x12\x1d\n\x15synthetic_cardinality\x18\x04 \x01(\x05\x12,\n\x15source_api_event_type\x18\x05 \x01(\x0e\x32\r.ApiEventType\"F\n\x08GuiEvent\x12\x1b\n\x04type\x18\x01 \x01(\x0e\x32\r.GuiEventType\x12\x1d\n\x15policy_search_task_pb\x18\x02 \x01(\x0c\"\xb6\x03\n\x11SearchOnNodeEvent\x12\x37\n\x0bval_results\x18\x01 \x03(\x0b\x32\".SearchOnNodeEvent.ValResultsEntry\x12\x39\n\x0ctest_results\x18\x02 \x03(\x0b\x32#.SearchOnNodeEvent.TestResultsEntry\x1a|\n\x10SearchOnNodeData\x12;\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32-.SearchOnNodeEvent.SearchOnNodeData.DataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1aV\n\x0fValResultsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.SearchOnNodeEvent.SearchOnNodeData:\x02\x38\x01\x1aW\n\x10TestResultsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.SearchOnNodeEvent.SearchOnNodeData:\x02\x38\x01\"\xca\x03\n\x10\x46itCompleteEvent\x12\x1c\n\x14\x65lapsed_time_seconds\x18\x01 \x01(\x02\x12\x36\n\x0bval_results\x18\x02 \x03(\x0b\x32!.FitCompleteEvent.ValResultsEntry\x12\x38\n\x0ctest_results\x18\x03 \x03(\x0b\x32\".FitCompleteEvent.TestResultsEntry\x1ay\n\x0f\x46itCompleteData\x12\x39\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32+.FitCompleteEvent.FitCompleteData.DataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1aT\n\x0fValResultsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.FitCompleteEvent.FitCompleteData:\x02\x38\x01\x1aU\n\x10TestResultsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.FitCompleteEvent.FitCompleteData:\x02\x38\x01\"\xf3\x03\n\x14\x41nalyzeCompleteEvent\x12\x1c\n\x14\x65lapsed_time_seconds\x18\x01 \x01(\x02\x12:\n\x0bval_results\x18\x02 \x03(\x0b\x32%.AnalyzeCompleteEvent.ValResultsEntry\x12<\n\x0ctest_results\x18\x03 \x03(\x0b\x32&.AnalyzeCompleteEvent.TestResultsEntry\x1a\x85\x01\n\x13\x41nalyzeCompleteData\x12\x41\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x33.AnalyzeCompleteEvent.AnalyzeCompleteData.DataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\\\n\x0fValResultsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).AnalyzeCompleteEvent.AnalyzeCompleteData:\x02\x38\x01\x1a]\n\x10TestResultsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).AnalyzeCompleteEvent.AnalyzeCompleteData:\x02\x38\x01\"?\n\x0bPolicyEvent\x12 \n\x0bpolicy_type\x18\x01 \x01(\x0e\x32\x0b.PolicyType\x12\x0e\n\x06policy\x18\x02 \x01(\x0c\"S\n\rApiErrorEvent\x12\x12\n\nerror_type\x18\x01 \x01(\t\x12\x15\n\rerror_context\x18\x02 \x01(\t\x12\x17\n\x0f\x65rror_traceback\x18\x03 \x01(\t\"\xbc\x04\n\x08LogEntry\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x03 \x01(\t\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\nevent_type\x18\x05 \x01(\x0e\x32\n.EventType\x12#\n\x0e\x61pi_event_data\x18\x06 \x01(\x0b\x32\t.ApiEventH\x00\x12+\n\x12\x64\x61taset_event_data\x18\x07 \x01(\x0b\x32\r.DatasetEventH\x00\x12\x37\n\x19search_on_node_event_data\x18\x08 \x01(\x0b\x32\x12.SearchOnNodeEventH\x00\x12\x34\n\x17\x66it_complete_event_data\x18\t \x01(\x0b\x32\x11.FitCompleteEventH\x00\x12<\n\x1b\x61nalyze_complete_event_data\x18\n \x01(\x0b\x32\x15.AnalyzeCompleteEventH\x00\x12#\n\x0egui_event_data\x18\x0b \x01(\x0b\x32\t.GuiEventH\x00\x12)\n\x11policy_event_data\x18\x0c \x01(\x0b\x32\x0c.PolicyEventH\x00\x12.\n\x14\x61pi_error_event_data\x18\r \x01(\x0b\x32\x0e.ApiErrorEventH\x00\x12\x13\n\x0bmac_address\x18\x0e \x01(\tB\x0c\n\nevent_data*\xa6\x02\n\x0c\x41piEventType\x12\x1a\n\x16\x41PI_EVENT_TYPE_UNKNOWN\x10\x00\x12\x0b\n\x07\x41UTOFIT\x10\x01\x12\x18\n\x14\x43ORE_FIND_FIT_POLICY\x10\x02\x12\x0c\n\x08\x43ORE_FIT\x10\x03\x12\x11\n\rCORE_ENSEMBLE\x10\x04\x12\x10\n\x0c\x43ORE_DISTILL\x10\x05\x12\x11\n\rCORE_PRETRAIN\x10\x06\x12!\n\x1d\x43ORE_FIND_AUGMENTATION_POLICY\x10\x07\x12\x12\n\x0eSEARCH_ON_NODE\x10\x08\x12\t\n\x05TRAIN\x10\t\x12\x14\n\x10SSL_ANALYZE_DATA\x10\n\x12\x11\n\rSSL_LOAD_FROM\x10\x0b\x12\x0c\n\x08REGISTER\x10\x0c\x12\x14\n\x10IMPORT_MASTERFUL\x10\r*P\n\x0cGuiEventType\x12\x1a\n\x16GUI_EVENT_TYPE_UNKNOWN\x10\x00\x12$\n SERIALIZED_POLICY_SEARCH_TASK_PB\x10\x01*\x87\x01\n\nPolicyType\x12\x17\n\x13POLICY_TYPE_UNKNOWN\x10\x00\x12\x13\n\x0fPOLICY_TYPE_FIT\x10\x01\x12\x18\n\x14POLICY_TYPE_ENSEMBLE\x10\x02\x12\x17\n\x13POLICY_TYPE_DISTILL\x10\x03\x12\x18\n\x14POLICY_TYPE_PRETRAIN\x10\x04*\xc9\x01\n\tEventType\x12\x16\n\x12\x45VENT_TYPE_UNKNOWN\x10\x00\x12\r\n\tAPI_EVENT\x10\x01\x12\x11\n\rDATASET_EVENT\x10\x02\x12\x18\n\x14SEARCH_ON_NODE_EVENT\x10\x03\x12\x16\n\x12\x46IT_COMPLETE_EVENT\x10\x04\x12\x1a\n\x16\x41NALYZE_COMPLETE_EVENT\x10\x05\x12\r\n\tGUI_EVENT\x10\x06\x12\x10\n\x0cPOLICY_EVENT\x10\x07\x12\x13\n\x0f\x41PI_ERROR_EVENT\x10\x08\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_APIEVENTTYPE = _descriptor.EnumDescriptor(
  name='ApiEventType',
  full_name='ApiEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='API_EVENT_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTOFIT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CORE_FIND_FIT_POLICY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CORE_FIT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CORE_ENSEMBLE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CORE_DISTILL', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CORE_PRETRAIN', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CORE_FIND_AUGMENTATION_POLICY', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCH_ON_NODE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRAIN', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SSL_ANALYZE_DATA', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SSL_LOAD_FROM', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REGISTER', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMPORT_MASTERFUL', index=13, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2573,
  serialized_end=2867,
)
_sym_db.RegisterEnumDescriptor(_APIEVENTTYPE)

ApiEventType = enum_type_wrapper.EnumTypeWrapper(_APIEVENTTYPE)
_GUIEVENTTYPE = _descriptor.EnumDescriptor(
  name='GuiEventType',
  full_name='GuiEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GUI_EVENT_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERIALIZED_POLICY_SEARCH_TASK_PB', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2869,
  serialized_end=2949,
)
_sym_db.RegisterEnumDescriptor(_GUIEVENTTYPE)

GuiEventType = enum_type_wrapper.EnumTypeWrapper(_GUIEVENTTYPE)
_POLICYTYPE = _descriptor.EnumDescriptor(
  name='PolicyType',
  full_name='PolicyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POLICY_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POLICY_TYPE_FIT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POLICY_TYPE_ENSEMBLE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POLICY_TYPE_DISTILL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POLICY_TYPE_PRETRAIN', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2952,
  serialized_end=3087,
)
_sym_db.RegisterEnumDescriptor(_POLICYTYPE)

PolicyType = enum_type_wrapper.EnumTypeWrapper(_POLICYTYPE)
_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='EventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EVENT_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='API_EVENT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATASET_EVENT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCH_ON_NODE_EVENT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIT_COMPLETE_EVENT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANALYZE_COMPLETE_EVENT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GUI_EVENT', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POLICY_EVENT', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='API_ERROR_EVENT', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3090,
  serialized_end=3291,
)
_sym_db.RegisterEnumDescriptor(_EVENTTYPE)

EventType = enum_type_wrapper.EnumTypeWrapper(_EVENTTYPE)
API_EVENT_TYPE_UNKNOWN = 0
AUTOFIT = 1
CORE_FIND_FIT_POLICY = 2
CORE_FIT = 3
CORE_ENSEMBLE = 4
CORE_DISTILL = 5
CORE_PRETRAIN = 6
CORE_FIND_AUGMENTATION_POLICY = 7
SEARCH_ON_NODE = 8
TRAIN = 9
SSL_ANALYZE_DATA = 10
SSL_LOAD_FROM = 11
REGISTER = 12
IMPORT_MASTERFUL = 13
GUI_EVENT_TYPE_UNKNOWN = 0
SERIALIZED_POLICY_SEARCH_TASK_PB = 1
POLICY_TYPE_UNKNOWN = 0
POLICY_TYPE_FIT = 1
POLICY_TYPE_ENSEMBLE = 2
POLICY_TYPE_DISTILL = 3
POLICY_TYPE_PRETRAIN = 4
EVENT_TYPE_UNKNOWN = 0
API_EVENT = 1
DATASET_EVENT = 2
SEARCH_ON_NODE_EVENT = 3
FIT_COMPLETE_EVENT = 4
ANALYZE_COMPLETE_EVENT = 5
GUI_EVENT = 6
POLICY_EVENT = 7
API_ERROR_EVENT = 8



_APIEVENT = _descriptor.Descriptor(
  name='ApiEvent',
  full_name='ApiEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='ApiEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_spec', full_name='ApiEvent.model_spec', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_model_spec', full_name='ApiEvent.extra_model_spec', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_spec', full_name='ApiEvent.data_spec', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='ApiEvent.version', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=183,
)


_DATASETEVENT = _descriptor.Descriptor(
  name='DatasetEvent',
  full_name='DatasetEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='labeled_cardinality', full_name='DatasetEvent.labeled_cardinality', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validation_cardinality', full_name='DatasetEvent.validation_cardinality', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unlabeled_cardinality', full_name='DatasetEvent.unlabeled_cardinality', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='synthetic_cardinality', full_name='DatasetEvent.synthetic_cardinality', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_api_event_type', full_name='DatasetEvent.source_api_event_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=369,
)


_GUIEVENT = _descriptor.Descriptor(
  name='GuiEvent',
  full_name='GuiEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='GuiEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_search_task_pb', full_name='GuiEvent.policy_search_task_pb', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=441,
)


_SEARCHONNODEEVENT_SEARCHONNODEDATA_DATAENTRY = _descriptor.Descriptor(
  name='DataEntry',
  full_name='SearchOnNodeEvent.SearchOnNodeData.DataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='SearchOnNodeEvent.SearchOnNodeData.DataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='SearchOnNodeEvent.SearchOnNodeData.DataEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=705,
)

_SEARCHONNODEEVENT_SEARCHONNODEDATA = _descriptor.Descriptor(
  name='SearchOnNodeData',
  full_name='SearchOnNodeEvent.SearchOnNodeData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='SearchOnNodeEvent.SearchOnNodeData.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SEARCHONNODEEVENT_SEARCHONNODEDATA_DATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=705,
)

_SEARCHONNODEEVENT_VALRESULTSENTRY = _descriptor.Descriptor(
  name='ValResultsEntry',
  full_name='SearchOnNodeEvent.ValResultsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='SearchOnNodeEvent.ValResultsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='SearchOnNodeEvent.ValResultsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=707,
  serialized_end=793,
)

_SEARCHONNODEEVENT_TESTRESULTSENTRY = _descriptor.Descriptor(
  name='TestResultsEntry',
  full_name='SearchOnNodeEvent.TestResultsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='SearchOnNodeEvent.TestResultsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='SearchOnNodeEvent.TestResultsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=795,
  serialized_end=882,
)

_SEARCHONNODEEVENT = _descriptor.Descriptor(
  name='SearchOnNodeEvent',
  full_name='SearchOnNodeEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='val_results', full_name='SearchOnNodeEvent.val_results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_results', full_name='SearchOnNodeEvent.test_results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SEARCHONNODEEVENT_SEARCHONNODEDATA, _SEARCHONNODEEVENT_VALRESULTSENTRY, _SEARCHONNODEEVENT_TESTRESULTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=882,
)


_FITCOMPLETEEVENT_FITCOMPLETEDATA_DATAENTRY = _descriptor.Descriptor(
  name='DataEntry',
  full_name='FitCompleteEvent.FitCompleteData.DataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='FitCompleteEvent.FitCompleteData.DataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='FitCompleteEvent.FitCompleteData.DataEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=705,
)

_FITCOMPLETEEVENT_FITCOMPLETEDATA = _descriptor.Descriptor(
  name='FitCompleteData',
  full_name='FitCompleteEvent.FitCompleteData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='FitCompleteEvent.FitCompleteData.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FITCOMPLETEEVENT_FITCOMPLETEDATA_DATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1049,
  serialized_end=1170,
)

_FITCOMPLETEEVENT_VALRESULTSENTRY = _descriptor.Descriptor(
  name='ValResultsEntry',
  full_name='FitCompleteEvent.ValResultsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='FitCompleteEvent.ValResultsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='FitCompleteEvent.ValResultsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1172,
  serialized_end=1256,
)

_FITCOMPLETEEVENT_TESTRESULTSENTRY = _descriptor.Descriptor(
  name='TestResultsEntry',
  full_name='FitCompleteEvent.TestResultsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='FitCompleteEvent.TestResultsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='FitCompleteEvent.TestResultsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1258,
  serialized_end=1343,
)

_FITCOMPLETEEVENT = _descriptor.Descriptor(
  name='FitCompleteEvent',
  full_name='FitCompleteEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='elapsed_time_seconds', full_name='FitCompleteEvent.elapsed_time_seconds', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val_results', full_name='FitCompleteEvent.val_results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_results', full_name='FitCompleteEvent.test_results', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FITCOMPLETEEVENT_FITCOMPLETEDATA, _FITCOMPLETEEVENT_VALRESULTSENTRY, _FITCOMPLETEEVENT_TESTRESULTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=885,
  serialized_end=1343,
)


_ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA_DATAENTRY = _descriptor.Descriptor(
  name='DataEntry',
  full_name='AnalyzeCompleteEvent.AnalyzeCompleteData.DataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AnalyzeCompleteEvent.AnalyzeCompleteData.DataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AnalyzeCompleteEvent.AnalyzeCompleteData.DataEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=705,
)

_ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA = _descriptor.Descriptor(
  name='AnalyzeCompleteData',
  full_name='AnalyzeCompleteEvent.AnalyzeCompleteData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='AnalyzeCompleteEvent.AnalyzeCompleteData.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA_DATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1523,
  serialized_end=1656,
)

_ANALYZECOMPLETEEVENT_VALRESULTSENTRY = _descriptor.Descriptor(
  name='ValResultsEntry',
  full_name='AnalyzeCompleteEvent.ValResultsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AnalyzeCompleteEvent.ValResultsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AnalyzeCompleteEvent.ValResultsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1658,
  serialized_end=1750,
)

_ANALYZECOMPLETEEVENT_TESTRESULTSENTRY = _descriptor.Descriptor(
  name='TestResultsEntry',
  full_name='AnalyzeCompleteEvent.TestResultsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AnalyzeCompleteEvent.TestResultsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AnalyzeCompleteEvent.TestResultsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1845,
)

_ANALYZECOMPLETEEVENT = _descriptor.Descriptor(
  name='AnalyzeCompleteEvent',
  full_name='AnalyzeCompleteEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='elapsed_time_seconds', full_name='AnalyzeCompleteEvent.elapsed_time_seconds', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val_results', full_name='AnalyzeCompleteEvent.val_results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_results', full_name='AnalyzeCompleteEvent.test_results', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA, _ANALYZECOMPLETEEVENT_VALRESULTSENTRY, _ANALYZECOMPLETEEVENT_TESTRESULTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1346,
  serialized_end=1845,
)


_POLICYEVENT = _descriptor.Descriptor(
  name='PolicyEvent',
  full_name='PolicyEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='policy_type', full_name='PolicyEvent.policy_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy', full_name='PolicyEvent.policy', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1847,
  serialized_end=1910,
)


_APIERROREVENT = _descriptor.Descriptor(
  name='ApiErrorEvent',
  full_name='ApiErrorEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_type', full_name='ApiErrorEvent.error_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_context', full_name='ApiErrorEvent.error_context', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_traceback', full_name='ApiErrorEvent.error_traceback', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1912,
  serialized_end=1995,
)


_LOGENTRY = _descriptor.Descriptor(
  name='LogEntry',
  full_name='LogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='LogEntry.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='LogEntry.session_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='LogEntry.client_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='LogEntry.timestamp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='LogEntry.event_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='api_event_data', full_name='LogEntry.api_event_data', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset_event_data', full_name='LogEntry.dataset_event_data', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_on_node_event_data', full_name='LogEntry.search_on_node_event_data', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fit_complete_event_data', full_name='LogEntry.fit_complete_event_data', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='analyze_complete_event_data', full_name='LogEntry.analyze_complete_event_data', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gui_event_data', full_name='LogEntry.gui_event_data', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_event_data', full_name='LogEntry.policy_event_data', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='api_error_event_data', full_name='LogEntry.api_error_event_data', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mac_address', full_name='LogEntry.mac_address', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event_data', full_name='LogEntry.event_data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1998,
  serialized_end=2570,
)

_APIEVENT.fields_by_name['type'].enum_type = _APIEVENTTYPE
_DATASETEVENT.fields_by_name['source_api_event_type'].enum_type = _APIEVENTTYPE
_GUIEVENT.fields_by_name['type'].enum_type = _GUIEVENTTYPE
_SEARCHONNODEEVENT_SEARCHONNODEDATA_DATAENTRY.containing_type = _SEARCHONNODEEVENT_SEARCHONNODEDATA
_SEARCHONNODEEVENT_SEARCHONNODEDATA.fields_by_name['data'].message_type = _SEARCHONNODEEVENT_SEARCHONNODEDATA_DATAENTRY
_SEARCHONNODEEVENT_SEARCHONNODEDATA.containing_type = _SEARCHONNODEEVENT
_SEARCHONNODEEVENT_VALRESULTSENTRY.fields_by_name['value'].message_type = _SEARCHONNODEEVENT_SEARCHONNODEDATA
_SEARCHONNODEEVENT_VALRESULTSENTRY.containing_type = _SEARCHONNODEEVENT
_SEARCHONNODEEVENT_TESTRESULTSENTRY.fields_by_name['value'].message_type = _SEARCHONNODEEVENT_SEARCHONNODEDATA
_SEARCHONNODEEVENT_TESTRESULTSENTRY.containing_type = _SEARCHONNODEEVENT
_SEARCHONNODEEVENT.fields_by_name['val_results'].message_type = _SEARCHONNODEEVENT_VALRESULTSENTRY
_SEARCHONNODEEVENT.fields_by_name['test_results'].message_type = _SEARCHONNODEEVENT_TESTRESULTSENTRY
_FITCOMPLETEEVENT_FITCOMPLETEDATA_DATAENTRY.containing_type = _FITCOMPLETEEVENT_FITCOMPLETEDATA
_FITCOMPLETEEVENT_FITCOMPLETEDATA.fields_by_name['data'].message_type = _FITCOMPLETEEVENT_FITCOMPLETEDATA_DATAENTRY
_FITCOMPLETEEVENT_FITCOMPLETEDATA.containing_type = _FITCOMPLETEEVENT
_FITCOMPLETEEVENT_VALRESULTSENTRY.fields_by_name['value'].message_type = _FITCOMPLETEEVENT_FITCOMPLETEDATA
_FITCOMPLETEEVENT_VALRESULTSENTRY.containing_type = _FITCOMPLETEEVENT
_FITCOMPLETEEVENT_TESTRESULTSENTRY.fields_by_name['value'].message_type = _FITCOMPLETEEVENT_FITCOMPLETEDATA
_FITCOMPLETEEVENT_TESTRESULTSENTRY.containing_type = _FITCOMPLETEEVENT
_FITCOMPLETEEVENT.fields_by_name['val_results'].message_type = _FITCOMPLETEEVENT_VALRESULTSENTRY
_FITCOMPLETEEVENT.fields_by_name['test_results'].message_type = _FITCOMPLETEEVENT_TESTRESULTSENTRY
_ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA_DATAENTRY.containing_type = _ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA
_ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA.fields_by_name['data'].message_type = _ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA_DATAENTRY
_ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA.containing_type = _ANALYZECOMPLETEEVENT
_ANALYZECOMPLETEEVENT_VALRESULTSENTRY.fields_by_name['value'].message_type = _ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA
_ANALYZECOMPLETEEVENT_VALRESULTSENTRY.containing_type = _ANALYZECOMPLETEEVENT
_ANALYZECOMPLETEEVENT_TESTRESULTSENTRY.fields_by_name['value'].message_type = _ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA
_ANALYZECOMPLETEEVENT_TESTRESULTSENTRY.containing_type = _ANALYZECOMPLETEEVENT
_ANALYZECOMPLETEEVENT.fields_by_name['val_results'].message_type = _ANALYZECOMPLETEEVENT_VALRESULTSENTRY
_ANALYZECOMPLETEEVENT.fields_by_name['test_results'].message_type = _ANALYZECOMPLETEEVENT_TESTRESULTSENTRY
_POLICYEVENT.fields_by_name['policy_type'].enum_type = _POLICYTYPE
_LOGENTRY.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGENTRY.fields_by_name['event_type'].enum_type = _EVENTTYPE
_LOGENTRY.fields_by_name['api_event_data'].message_type = _APIEVENT
_LOGENTRY.fields_by_name['dataset_event_data'].message_type = _DATASETEVENT
_LOGENTRY.fields_by_name['search_on_node_event_data'].message_type = _SEARCHONNODEEVENT
_LOGENTRY.fields_by_name['fit_complete_event_data'].message_type = _FITCOMPLETEEVENT
_LOGENTRY.fields_by_name['analyze_complete_event_data'].message_type = _ANALYZECOMPLETEEVENT
_LOGENTRY.fields_by_name['gui_event_data'].message_type = _GUIEVENT
_LOGENTRY.fields_by_name['policy_event_data'].message_type = _POLICYEVENT
_LOGENTRY.fields_by_name['api_error_event_data'].message_type = _APIERROREVENT
_LOGENTRY.oneofs_by_name['event_data'].fields.append(
  _LOGENTRY.fields_by_name['api_event_data'])
_LOGENTRY.fields_by_name['api_event_data'].containing_oneof = _LOGENTRY.oneofs_by_name['event_data']
_LOGENTRY.oneofs_by_name['event_data'].fields.append(
  _LOGENTRY.fields_by_name['dataset_event_data'])
_LOGENTRY.fields_by_name['dataset_event_data'].containing_oneof = _LOGENTRY.oneofs_by_name['event_data']
_LOGENTRY.oneofs_by_name['event_data'].fields.append(
  _LOGENTRY.fields_by_name['search_on_node_event_data'])
_LOGENTRY.fields_by_name['search_on_node_event_data'].containing_oneof = _LOGENTRY.oneofs_by_name['event_data']
_LOGENTRY.oneofs_by_name['event_data'].fields.append(
  _LOGENTRY.fields_by_name['fit_complete_event_data'])
_LOGENTRY.fields_by_name['fit_complete_event_data'].containing_oneof = _LOGENTRY.oneofs_by_name['event_data']
_LOGENTRY.oneofs_by_name['event_data'].fields.append(
  _LOGENTRY.fields_by_name['analyze_complete_event_data'])
_LOGENTRY.fields_by_name['analyze_complete_event_data'].containing_oneof = _LOGENTRY.oneofs_by_name['event_data']
_LOGENTRY.oneofs_by_name['event_data'].fields.append(
  _LOGENTRY.fields_by_name['gui_event_data'])
_LOGENTRY.fields_by_name['gui_event_data'].containing_oneof = _LOGENTRY.oneofs_by_name['event_data']
_LOGENTRY.oneofs_by_name['event_data'].fields.append(
  _LOGENTRY.fields_by_name['policy_event_data'])
_LOGENTRY.fields_by_name['policy_event_data'].containing_oneof = _LOGENTRY.oneofs_by_name['event_data']
_LOGENTRY.oneofs_by_name['event_data'].fields.append(
  _LOGENTRY.fields_by_name['api_error_event_data'])
_LOGENTRY.fields_by_name['api_error_event_data'].containing_oneof = _LOGENTRY.oneofs_by_name['event_data']
DESCRIPTOR.message_types_by_name['ApiEvent'] = _APIEVENT
DESCRIPTOR.message_types_by_name['DatasetEvent'] = _DATASETEVENT
DESCRIPTOR.message_types_by_name['GuiEvent'] = _GUIEVENT
DESCRIPTOR.message_types_by_name['SearchOnNodeEvent'] = _SEARCHONNODEEVENT
DESCRIPTOR.message_types_by_name['FitCompleteEvent'] = _FITCOMPLETEEVENT
DESCRIPTOR.message_types_by_name['AnalyzeCompleteEvent'] = _ANALYZECOMPLETEEVENT
DESCRIPTOR.message_types_by_name['PolicyEvent'] = _POLICYEVENT
DESCRIPTOR.message_types_by_name['ApiErrorEvent'] = _APIERROREVENT
DESCRIPTOR.message_types_by_name['LogEntry'] = _LOGENTRY
DESCRIPTOR.enum_types_by_name['ApiEventType'] = _APIEVENTTYPE
DESCRIPTOR.enum_types_by_name['GuiEventType'] = _GUIEVENTTYPE
DESCRIPTOR.enum_types_by_name['PolicyType'] = _POLICYTYPE
DESCRIPTOR.enum_types_by_name['EventType'] = _EVENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ApiEvent = _reflection.GeneratedProtocolMessageType('ApiEvent', (_message.Message,), {
  'DESCRIPTOR' : _APIEVENT,
  '__module__' : 'masterful.proto.log_pb2'
  # @@protoc_insertion_point(class_scope:ApiEvent)
  })
_sym_db.RegisterMessage(ApiEvent)

DatasetEvent = _reflection.GeneratedProtocolMessageType('DatasetEvent', (_message.Message,), {
  'DESCRIPTOR' : _DATASETEVENT,
  '__module__' : 'masterful.proto.log_pb2'
  # @@protoc_insertion_point(class_scope:DatasetEvent)
  })
_sym_db.RegisterMessage(DatasetEvent)

GuiEvent = _reflection.GeneratedProtocolMessageType('GuiEvent', (_message.Message,), {
  'DESCRIPTOR' : _GUIEVENT,
  '__module__' : 'masterful.proto.log_pb2'
  # @@protoc_insertion_point(class_scope:GuiEvent)
  })
_sym_db.RegisterMessage(GuiEvent)

SearchOnNodeEvent = _reflection.GeneratedProtocolMessageType('SearchOnNodeEvent', (_message.Message,), {

  'SearchOnNodeData' : _reflection.GeneratedProtocolMessageType('SearchOnNodeData', (_message.Message,), {

    'DataEntry' : _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), {
      'DESCRIPTOR' : _SEARCHONNODEEVENT_SEARCHONNODEDATA_DATAENTRY,
      '__module__' : 'masterful.proto.log_pb2'
      # @@protoc_insertion_point(class_scope:SearchOnNodeEvent.SearchOnNodeData.DataEntry)
      })
    ,
    'DESCRIPTOR' : _SEARCHONNODEEVENT_SEARCHONNODEDATA,
    '__module__' : 'masterful.proto.log_pb2'
    # @@protoc_insertion_point(class_scope:SearchOnNodeEvent.SearchOnNodeData)
    })
  ,

  'ValResultsEntry' : _reflection.GeneratedProtocolMessageType('ValResultsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SEARCHONNODEEVENT_VALRESULTSENTRY,
    '__module__' : 'masterful.proto.log_pb2'
    # @@protoc_insertion_point(class_scope:SearchOnNodeEvent.ValResultsEntry)
    })
  ,

  'TestResultsEntry' : _reflection.GeneratedProtocolMessageType('TestResultsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SEARCHONNODEEVENT_TESTRESULTSENTRY,
    '__module__' : 'masterful.proto.log_pb2'
    # @@protoc_insertion_point(class_scope:SearchOnNodeEvent.TestResultsEntry)
    })
  ,
  'DESCRIPTOR' : _SEARCHONNODEEVENT,
  '__module__' : 'masterful.proto.log_pb2'
  # @@protoc_insertion_point(class_scope:SearchOnNodeEvent)
  })
_sym_db.RegisterMessage(SearchOnNodeEvent)
_sym_db.RegisterMessage(SearchOnNodeEvent.SearchOnNodeData)
_sym_db.RegisterMessage(SearchOnNodeEvent.SearchOnNodeData.DataEntry)
_sym_db.RegisterMessage(SearchOnNodeEvent.ValResultsEntry)
_sym_db.RegisterMessage(SearchOnNodeEvent.TestResultsEntry)

FitCompleteEvent = _reflection.GeneratedProtocolMessageType('FitCompleteEvent', (_message.Message,), {

  'FitCompleteData' : _reflection.GeneratedProtocolMessageType('FitCompleteData', (_message.Message,), {

    'DataEntry' : _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), {
      'DESCRIPTOR' : _FITCOMPLETEEVENT_FITCOMPLETEDATA_DATAENTRY,
      '__module__' : 'masterful.proto.log_pb2'
      # @@protoc_insertion_point(class_scope:FitCompleteEvent.FitCompleteData.DataEntry)
      })
    ,
    'DESCRIPTOR' : _FITCOMPLETEEVENT_FITCOMPLETEDATA,
    '__module__' : 'masterful.proto.log_pb2'
    # @@protoc_insertion_point(class_scope:FitCompleteEvent.FitCompleteData)
    })
  ,

  'ValResultsEntry' : _reflection.GeneratedProtocolMessageType('ValResultsEntry', (_message.Message,), {
    'DESCRIPTOR' : _FITCOMPLETEEVENT_VALRESULTSENTRY,
    '__module__' : 'masterful.proto.log_pb2'
    # @@protoc_insertion_point(class_scope:FitCompleteEvent.ValResultsEntry)
    })
  ,

  'TestResultsEntry' : _reflection.GeneratedProtocolMessageType('TestResultsEntry', (_message.Message,), {
    'DESCRIPTOR' : _FITCOMPLETEEVENT_TESTRESULTSENTRY,
    '__module__' : 'masterful.proto.log_pb2'
    # @@protoc_insertion_point(class_scope:FitCompleteEvent.TestResultsEntry)
    })
  ,
  'DESCRIPTOR' : _FITCOMPLETEEVENT,
  '__module__' : 'masterful.proto.log_pb2'
  # @@protoc_insertion_point(class_scope:FitCompleteEvent)
  })
_sym_db.RegisterMessage(FitCompleteEvent)
_sym_db.RegisterMessage(FitCompleteEvent.FitCompleteData)
_sym_db.RegisterMessage(FitCompleteEvent.FitCompleteData.DataEntry)
_sym_db.RegisterMessage(FitCompleteEvent.ValResultsEntry)
_sym_db.RegisterMessage(FitCompleteEvent.TestResultsEntry)

AnalyzeCompleteEvent = _reflection.GeneratedProtocolMessageType('AnalyzeCompleteEvent', (_message.Message,), {

  'AnalyzeCompleteData' : _reflection.GeneratedProtocolMessageType('AnalyzeCompleteData', (_message.Message,), {

    'DataEntry' : _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), {
      'DESCRIPTOR' : _ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA_DATAENTRY,
      '__module__' : 'masterful.proto.log_pb2'
      # @@protoc_insertion_point(class_scope:AnalyzeCompleteEvent.AnalyzeCompleteData.DataEntry)
      })
    ,
    'DESCRIPTOR' : _ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA,
    '__module__' : 'masterful.proto.log_pb2'
    # @@protoc_insertion_point(class_scope:AnalyzeCompleteEvent.AnalyzeCompleteData)
    })
  ,

  'ValResultsEntry' : _reflection.GeneratedProtocolMessageType('ValResultsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ANALYZECOMPLETEEVENT_VALRESULTSENTRY,
    '__module__' : 'masterful.proto.log_pb2'
    # @@protoc_insertion_point(class_scope:AnalyzeCompleteEvent.ValResultsEntry)
    })
  ,

  'TestResultsEntry' : _reflection.GeneratedProtocolMessageType('TestResultsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ANALYZECOMPLETEEVENT_TESTRESULTSENTRY,
    '__module__' : 'masterful.proto.log_pb2'
    # @@protoc_insertion_point(class_scope:AnalyzeCompleteEvent.TestResultsEntry)
    })
  ,
  'DESCRIPTOR' : _ANALYZECOMPLETEEVENT,
  '__module__' : 'masterful.proto.log_pb2'
  # @@protoc_insertion_point(class_scope:AnalyzeCompleteEvent)
  })
_sym_db.RegisterMessage(AnalyzeCompleteEvent)
_sym_db.RegisterMessage(AnalyzeCompleteEvent.AnalyzeCompleteData)
_sym_db.RegisterMessage(AnalyzeCompleteEvent.AnalyzeCompleteData.DataEntry)
_sym_db.RegisterMessage(AnalyzeCompleteEvent.ValResultsEntry)
_sym_db.RegisterMessage(AnalyzeCompleteEvent.TestResultsEntry)

PolicyEvent = _reflection.GeneratedProtocolMessageType('PolicyEvent', (_message.Message,), {
  'DESCRIPTOR' : _POLICYEVENT,
  '__module__' : 'masterful.proto.log_pb2'
  # @@protoc_insertion_point(class_scope:PolicyEvent)
  })
_sym_db.RegisterMessage(PolicyEvent)

ApiErrorEvent = _reflection.GeneratedProtocolMessageType('ApiErrorEvent', (_message.Message,), {
  'DESCRIPTOR' : _APIERROREVENT,
  '__module__' : 'masterful.proto.log_pb2'
  # @@protoc_insertion_point(class_scope:ApiErrorEvent)
  })
_sym_db.RegisterMessage(ApiErrorEvent)

LogEntry = _reflection.GeneratedProtocolMessageType('LogEntry', (_message.Message,), {
  'DESCRIPTOR' : _LOGENTRY,
  '__module__' : 'masterful.proto.log_pb2'
  # @@protoc_insertion_point(class_scope:LogEntry)
  })
_sym_db.RegisterMessage(LogEntry)


_SEARCHONNODEEVENT_SEARCHONNODEDATA_DATAENTRY._options = None
_SEARCHONNODEEVENT_VALRESULTSENTRY._options = None
_SEARCHONNODEEVENT_TESTRESULTSENTRY._options = None
_FITCOMPLETEEVENT_FITCOMPLETEDATA_DATAENTRY._options = None
_FITCOMPLETEEVENT_VALRESULTSENTRY._options = None
_FITCOMPLETEEVENT_TESTRESULTSENTRY._options = None
_ANALYZECOMPLETEEVENT_ANALYZECOMPLETEDATA_DATAENTRY._options = None
_ANALYZECOMPLETEEVENT_VALRESULTSENTRY._options = None
_ANALYZECOMPLETEEVENT_TESTRESULTSENTRY._options = None
# @@protoc_insertion_point(module_scope)
